abacusai.pipeline_step_version_reference — AbacusAI documentation

# abacusai.pipeline_step_version_reference

## Classes

`PipelineStepVersionReference` | A reference from a pipeline step version to the versions that were output from the pipeline step.

## Module Contents

class abacusai.pipeline_step_version_reference.PipelineStepVersionReference(client, pipelineStepVersionReferenceId=None, pipelineStepVersion=None, objectType=None, datasetVersion=None, modelVersion=None, deploymentVersion=None, batchPredictionId=None, modelMonitorVersion=None, notebookVersion=None, featureGroupVersion=None, status=None, error=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A reference from a pipeline step version to the versions that were output from the pipeline step.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - pipelineStepVersionReferenceId (str) – The id of the reference.

    - pipelineStepVersion (str) – The pipeline step version the reference is connected to.

    - objectType (str) – The object type of the reference.

    - datasetVersion (str) – The dataset version the reference is connected to.

    - modelVersion (str) – The model version the reference is connected to.

    - deploymentVersion (str) – The deployment version the reference is connected to.

    - batchPredictionId (str) – The batch prediction id the reference is connected to.

    - modelMonitorVersion (str) – The model monitor version the reference is connected to.

    - notebookVersion (str) – The notebook version the reference is connected to.

    - featureGroupVersion (str) – The feature group version the reference is connected to.

    - status (str) – The status of the reference

    - error (str) – The error message if the reference is in an error state.

  pipeline_step_version_reference_id
  pipeline_step_version
  object_type
  dataset_version
  model_version
  deployment_version
  batch_prediction_id
  model_monitor_version
  notebook_version
  feature_group_version
  status
  error
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict